@@ -8,7 +8,7 @@ from vdocipher import Video
 
 class TestVideo:
 
-    def test_video_get_list(self, vdocipher, video):
+    def test_video_get_list(self, vdocipher, ):
         videos = vdocipher.Video().get_list()
 
         assert len(videos) > 0
@@ -42,7 +42,6 @@ class TestVideo:
         vdocipher.Video(id=upload_credentials.video_id).delete()
 
     def test_video_upload(self, video: Video):
-
         assert isinstance(video, Video)
         assert video.id
 
@@ -53,17 +52,28 @@ class TestVideo:
         assert "Successfully deleted 1 videos" in response.json()['message']
 
     def test_video_get(self, video):
-        video_obj = video.get_video()
+        video_obj = video.get()
 
         assert video_obj.id == video.id
         assert video_obj.title == video.title
         assert video_obj.status == 'PRE-Upload'
 
-    def test_create_otp(self, video):
+    def test_video_get_query(self, vdocipher):
+        videos_to_test = [vdocipher.Video(title=f'test-query-{i}').upload('resources/test_file.mp4') for i in range(3)]
 
+        query_test = 'test-query-2'
+        videos_list = vdocipher.Video().query(query=query_test)
+
+        assert len(videos_list) > 0
+
+        [isinstance(video_obj, Video) for video_obj in videos_list]
+
+        assert videos_list[0].title == query_test
+
+        [video.delete() for video in videos_to_test]
+
+    def test_create_otp(self, video):
         otp = video.create_otp()
 
         assert otp.otp
         assert otp.playback_info
-
-
